# Custom Logger Package

## 개요

이 프로젝트는 Python 애플리케이션을 위한 사용자 정의 로깅 설정을 제공합니다. `setup_logger` 함수를 사용하면, 애플리케이션의 다양한 부분에서 일관된 로깅 설정을 적용할 수 있습니다. 로그 파일은 호출하는 스크립트가 위치한 디렉토리에 생성됩니다.

## 기능

- 로그 파일 자동 생성: 스크립트 실행 위치에 기반한 로그 디렉토리에 로그 파일을 자동으로 생성합니다.
- 쉬운 통합: 다양한 Python 스크립트에서 쉽게 사용할 수 있습니다.
- 사용자 정의 가능: 로그 디렉토리와 로거 이름을 사용자가 정의할 수 있습니다.

## 설치 방법

이 패키지는 아직 공식 Python 패키지 저장소에 등록되지 않았기 때문에, GitHub 레포지토리나 내부 패키지 저장소를 통해 설치해야 합니다.

```bash
pip install waylake-utils
```

## 사용 방법

1. 패키지를 import합니다.

```python
from waylake import setup_logger
```

2. 로거를 설정합니다. `__file__`을 인자로 전달하여 현재 스크립트의 위치에 로그 파일을 생성합니다.

```python
logger = setup_logger('my_logger_name', __file__)
logger = setup_logger(name='logger_name', caller_file=__file__, log_dir='./logs')
```

3. 로그를 기록합니다.

```python
logger.info("This is an info message")
logger.error("This is an error message")
```

## 라이선스
